@@ -278,7 +278,7 @@ class TEI:
         for title in struct.find_all("title"):
             if "level" in title.attrs:
                 titles_dict[title["level"]] = title.text
-        if titles_dict:
+        if len(titles_dict) > 0:
             citation.titles = CitationTitles.from_dict(titles_dict)
         citation.main_title = citation.titles.additional_properties.get("a", None)
         scopes_dict = {}
@@ -292,7 +292,7 @@ class TEI:
                 if not val:
                     val = scope.text
                 scopes_dict[scope["unit"]] = str(val)
-        if scopes_dict:
+        if len(scopes_dict) > 0:
             citation.scopes = CitationScopes.from_dict(scopes_dict)
         return citation
 
